==> ingdao-0.0.2.tar.gz: lib/dataflow/invlog/web/entity/entwebreq.dart <==

import '../../../entity/dfbaseentity.dart';
import '../../../entity/dfdbentity.dart';
import '../../../entity/dfwebentity.dart';
import '../../../field/dfbasefield.dart';
import '../../../field/dfdbfield.dart';
import '../../../field/dffieldtype.dart';
import '../../../control/dfconverter.dart';
import '../../../model/dfwebmodel.dart';
import '../../../control/dfquery.dart';
import 'webreqfield.dart';

class WebReq extends DfDbEntity with WebReqField {
    
  WebReq ({String id, String name, bool encrypt, String serverUrl, Map<String,dynamic> commonHeaders, SslPinningCri sslPinningCri, DfQuery query, bool success, Map<String,dynamic> headers}) : super(name: "log_webreq") {
    String sslPinningKeys;
    String sslPinningTypeStr;
    if (sslPinningCri != null) {
      sslPinningKeys = DfConverter.arrToString(sslPinningCri.shakeys);
      sslPinningTypeStr = sslPinningCri.shatype.name;
    }

    String contextPath;
    String pathVariablesStr;
    String reqParamStr;
    String reqBodyStr;
    if (query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      DfWebEntity entity = query.entityJoin.entities[0] as DfWebEntity;
      final reqParam = entity.convertToWebReqParam(query);
      if (reqParam != null) {
        pathVariablesStr = DfConverter.arrToString(reqParam.pathVariables);
        reqParamStr = DfConverter.dictToJsonString(reqParam.reqParams);
        reqBodyStr = DfConverter.dictToJsonString(reqParam.reqBody);
      }

      contextPath = entity.name;
    }
          

    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), value: id);
    fName = DfDbField(entity: this, name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: name);
    fEncrypt = DfDbField(entity: this, name: "encrypt", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: DfConverter.boolToInt(encrypt));
    fServerUrl = DfDbField(entity: this, name: "serverurl", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), value: serverUrl);
    fCommonHeaders = DfDbField(entity: this, name: "commonheaders", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: DfConverter.dictToJsonString(commonHeaders));    
    fSslPinningList = DfDbField(entity: this, name: "sslpinninglist", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: sslPinningKeys);
    fSslPinningType = DfDbField(entity: this, name: "sslpinningtype", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: sslPinningTypeStr);
    fContextPath = DfDbField(entity: this, name: "contextpath", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: contextPath);
    fHttpMethod = DfDbField(entity: this, name: "httpmethod", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: query.purpose.name);
    fPathVariables = DfDbField(entity: this, name: "pathvariables", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: pathVariablesStr);
    fReqParams = DfDbField(entity: this, name: "reqparams", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: reqParamStr);
    fReqBody = DfDbField(entity: this, name: "reqbody", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: reqBodyStr);
    fCreatedAt = DfDbField(entity: this, name: "createdat", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(), value: DateTime.now());
    fSuccess = DfDbField(entity: this, name: "success", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: DfConverter.boolToInt(success));
    fHeaders = DfDbField(entity: this, name: "headers", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: DfConverter.dictToJsonString(headers));    
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [
       fId,
       fName,
       fEncrypt,
       fServerUrl,
       fCommonHeaders,
       fSslPinningList,
       fSslPinningType,
       fContextPath,
       fHttpMethod,
       fPathVariables,
       fReqParams,
       fReqBody,
       fCreatedAt,
       fSuccess
     ];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return WebReq();
  }
}

==> ingdao-0.0.5.tar.gz: lib/dataflow/invlog/web/entity/entwebreq.dart <==

import '../../../entity/dfbaseentity.dart';
import '../../../entity/dfdbentity.dart';
import '../../../entity/dfwebentity.dart';
import '../../../field/dfbasefield.dart';
import '../../../field/dfdbfield.dart';
import '../../../field/dffieldtype.dart';
import '../../../control/dfconverter.dart';
import '../../../model/dfwebmodel.dart';
import '../../../control/dfquery.dart';
import 'webreqfield.dart';

class WebReq extends DfDbEntity with WebReqField {
    
  WebReq ({String id, String name, bool encrypt, String serverUrl, Map<String,dynamic> commonHeaders, SslPinningCri sslPinningCri, DfQuery query, bool success, Map<String,dynamic> headers}) : super(name: "log_webreq") {
    String sslPinningKeys;
    String sslPinningTypeStr;
    if (sslPinningCri != null) {
      sslPinningKeys = DfConverter.arrToString(sslPinningCri.shakeys);
      sslPinningTypeStr = sslPinningCri.shatype.name;
    }

    String contextPath;
    String pathVariablesStr;
    String reqParamStr;
    String reqBodyStr;
    if (query.entityJoin != null && query.entityJoin.entities != null && query.entityJoin.entities.length > 0) {
      DfWebEntity entity = query.entityJoin.entities[0] as DfWebEntity;
      final reqParam = entity.convertToWebReqParam(query);
      if (reqParam != null) {
        pathVariablesStr = DfConverter.arrToString(reqParam.pathVariables);
        reqParamStr = DfConverter.dictToJsonString(reqParam.reqParams);
        reqBodyStr = DfConverter.dictToJsonString(reqParam.reqBody);
      }

      contextPath = entity.entityName;
    }
          

    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), value: id);
    fName = DfDbField(entity: this, name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: name);
    fEncrypt = DfDbField(entity: this, name: "encrypt", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: DfConverter.boolToInt(encrypt));
    fServerUrl = DfDbField(entity: this, name: "serverurl", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), value: serverUrl);
    fCommonHeaders = DfDbField(entity: this, name: "commonheaders", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: DfConverter.dictToJsonString(commonHeaders));    
    fSslPinningList = DfDbField(entity: this, name: "sslpinninglist", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: sslPinningKeys);
    fSslPinningType = DfDbField(entity: this, name: "sslpinningtype", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: sslPinningTypeStr);
    fContextPath = DfDbField(entity: this, name: "contextpath", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: contextPath);
    fHttpMethod = DfDbField(entity: this, name: "httpmethod", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: query.purpose.name);
    fPathVariables = DfDbField(entity: this, name: "pathvariables", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: pathVariablesStr);
    fReqParams = DfDbField(entity: this, name: "reqparams", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: reqParamStr);
    fReqBody = DfDbField(entity: this, name: "reqbody", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: reqBodyStr);
    fCreatedAt = DfDbField(entity: this, name: "createdat", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(), value: DateTime.now());
    fSuccess = DfDbField(entity: this, name: "success", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer(), value: DfConverter.boolToInt(success));
    fHeaders = DfDbField(entity: this, name: "headers", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), value: DfConverter.dictToJsonString(headers));    
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [
       fId,
       fName,
       fEncrypt,
       fServerUrl,
       fCommonHeaders,
       fSslPinningList,
       fSslPinningType,
       fContextPath,
       fHttpMethod,
       fPathVariables,
       fReqParams,
       fReqBody,
       fCreatedAt,
       fSuccess
     ];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return WebReq();
  }

  @override
  Type myType() {
    return WebReq;
  }
}
